@@ -105,6 +105,8 @@ def do_oslc_query(inputargs=None):
     parser.add_argument('--pagesize', default=200, type=int, help="Page size for OSLC query (default 200)")
     parser.add_argument('--typesystemreport', default=None, help="Load the specified project/configuration and then produce a simple HTML type system report of resource shapes/properties/enumerations to this file" )
     parser.add_argument('--cachedays', default=1,type=int, help="The number of days for caching received data, default 1. To disable caching use -WW. To keep using a non-default cache period you must specify this value every time" )
+    parser.add_argument('--saverawresults', default=None, help="Save the raw results as XML to this path/file prefix - pages are numbered starting from 0000" )
+    parser.add_argument('--saveprocessedresults', default=None, help="Save the processed results as JSON to this path/file" )
 
     # saved credentials
     parser.add_argument('-0', '--savecreds', default=None, help="Save obfuscated credentials file for use with readcreds, then exit - this stores jazzurl, jts, appstring, username and password")
@@ -456,6 +458,7 @@ def do_oslc_query(inputargs=None):
                     ,pagesize=args.pagesize
                     ,resolvenames = args.resolvenames
                     ,totalize=args.totalize
+                    ,saverawresults=args.saverawresults
                     )
 
     if args.debugprint:
@@ -509,27 +512,49 @@ def do_oslc_query(inputargs=None):
 
     resultsentries = "entries" if len(results.keys())!=1 else "entry"
 
+    if args.saveprocessedresults:
+        open(args.saveprocessedresults+"_before.json","wt").write(json.dumps(results))
+        
     print( f"Query result has {len(results.keys())} {resultsentries}" )
 
-    # THIS IS UNTESTED!
+    # COMPARE IS UNTESTED!
     if args.outputfile or args.compareresults:
         # write to CSV and/or compare with CSV
+        # FIRST merge columns with same name - this merges types across components based on name
+        # which is only need for queries in a GC. NOTE this doesn't attempt to use RDF URIs which it probably should :-o
+        # but having different (as in totally different) types with same name is not exactly human-friendly!
         # build a list of all properties - these will be column headings for the CSV
         headings = []
+        rawheadings = [] # this is used so headings are only resolved once - the raw headings are remembered in this list
+        actualheadings = {}
         for k, v in list(results.items()):
             # add the URI to the value so it will be exported (first char is $ so the uri will always be in first column after the column titles are sorted)
             v["$uri"] = k
             for sk in list(v.keys()):
-                sk1 = queryon.resolve_uri_to_name(sk)
-                if sk1 is not None:
-                    logger.debug(f"renaming {sk=} {sk1=}" )
-                    existing = v[sk]
-                    del v[sk]
-                    v[sk1] = existing
+                sk1 = queryon.resolve_uri_to_name(sk) if args.resolvenames else sk
+                if sk not in rawheadings:
+                    rawheadings.append(sk)
+                    if sk1 == sk: # if heading name hasn't been resolved before
+                        sk1 = queryon.resolve_uri_to_name(sk) # always resolve - only for headings
+                    if sk1 not in headings:
+                        headings.append(sk1)
+                    actualheadings[sk] = sk1
+#                    # also store the reverse actual->raw
+#                    actualheadings[sk1] = sk
+                    logger.info( f"Mapping {sk} to {sk1}" )
                 else:
-                    sk1 = sk
-                if sk1 not in headings:
-                    headings.append(sk1)
+                    sk1 = actualheadings[sk]
+                if sk!=sk1:
+                    logger.debug(f"renaming {sk=} {sk1=}" )
+                    # if ernaming need to merge column content!
+                    existing = v[sk]
+                    otherexisting = v.get(sk1)
+                    del v[sk]
+                    if existing and otherexisting:
+                        if existing != otherexisting:
+                            logger.info( f"MERGE {existing=} {otherexisting=}" )
+                            burp
+                    v[sk1] = otherexisting if otherexisting else existing
 
         fieldnames = sorted(headings)
         if args.outputfile:
@@ -538,6 +563,9 @@ def do_oslc_query(inputargs=None):
                 writer.writeheader()
                 for k, v in results.items():
                     writer.writerow(v)
+                    
+        if args.saveprocessedresults:
+            open(args.saveprocessedresults+"_after.json","wt").write(json.dumps(results))
 
         if args.compareresults:
             # a simple test by comparing the received results with a saved CSV from a previous run
@@ -600,7 +628,7 @@ def do_oslc_query(inputargs=None):
             print( f"{len(results.keys())} results and {args.nresults} expected - Passed :-)" )
 
     if args.xmloutputfile is not None:
-    
+        # retrieve all resources in the results to XML
         # ensure output folder exists
         args.xmloutputfile = os.path.abspath(args.xmloutputfile)
         outputpath = os.path.split(args.xmloutputfile)[0]
